@@ -3,17 +3,16 @@
 package POE::Filter::Map;
 
 use strict;
-use POE::Filter;
 
-use vars qw($VERSION @ISA);
-$VERSION = do {my($r)=(q$Revision: 2220 $=~/(\d+)/);sprintf"1.%04d",$r};
-@ISA = qw(POE::Filter);
+use vars qw($VERSION);
+$VERSION = do {my@r=(q$Revision: 1.5 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
-use Carp qw(croak carp);
+use Carp qw(croak);
 
-sub BUFFER   () { 0 }
+sub CODEBOTH () { 0 }
 sub CODEGET  () { 1 }
 sub CODEPUT  () { 2 }
+sub BUFFER   () { 3 }
 
 #------------------------------------------------------------------------------
 
@@ -21,33 +20,38 @@ sub new {
   my $type = shift;
   croak "$type must be given an even number of parameters" if @_ & 1;
   my %params = @_;
-  
-  croak "$type requires a Code or both Get and Put parameters" unless (
-    defined($params{Code}) or
-    (defined($params{Get}) and defined($params{Put}))
-  );
-  croak "Code element is not a subref"
-    unless (defined $params{Code} ? ref $params{Code} eq 'CODE' : 1);
-  croak "Get or Put element is not a subref"
-    unless ((defined $params{Get} ? (ref $params{Get} eq 'CODE') : 1)
-      and   (defined $params{Put} ? (ref $params{Put} eq 'CODE') : 1));
 
-  my $self = bless [
-    [ ],           # BUFFER
-    $params{Code} || $params{Get},  # CODEGET
-    $params{Code} || $params{Put},  # CODEPUT
-  ], $type;
+  # -><- It might be better here for Code to set Get and Put first,
+  # and then have Get and/or Put override that.  During the filter's
+  # normal running (in the hotter code path), you won't need to keep
+  # checking CODEBOTH or (CODEGET OR CODEPUT).  Rather, you'll just
+  # check CODEGET or CODEPUT (depending on the direction data is
+  # headed).
+
+  croak "$type requires a Code or both Get and Put parameters" unless
+    (defined($params{Code}) ||
+     (defined($params{Get}) && defined($params{Put})));
+
+  my $self = bless
+    [ $params{Code}, # CODEBOTH
+      $params{Get},  # CODEGET
+      $params{Put},  # CODEPUT
+      [ ],           # BUFFER
+    ], $type;
 }
 
 #------------------------------------------------------------------------------
-# get() is inherited from POE::Filter.
-# clone() is inherited from POE::Filter.
+
+sub get {
+  my ($self, $data) = @_;
+  [ map &{$self->[CODEGET] || $self->[CODEBOTH]}, @$data ];
+}
 
 #------------------------------------------------------------------------------
 
 sub put {
   my ($self, $data) = @_;
-  [ map { $self->[CODEPUT]->($_) } @$data ];
+  [ map &{$self->[CODEPUT] || $self->[CODEBOTH]}, @$data ];
 }
 
 #------------------------------------------------------------------------------
@@ -66,7 +70,7 @@ sub get_one {
 
   return [ ] unless @{$self->[BUFFER]};
   my $next_record = shift @{$self->[BUFFER]};
-  return [ map { $self->[CODEGET]->($_) } $next_record ];
+  return [ map &{$self->[CODEGET] || $self->[CODEBOTH]}, $next_record ];
 }
 
 #------------------------------------------------------------------------------
@@ -83,19 +87,13 @@ sub get_pending {
 
 sub modify {
   my ($self, %params) = @_;
-
   for (keys %params) {
-    (carp("Modify $_ element must be given a coderef") and next) unless (ref $params{$_} eq 'CODE');
-    if (lc eq 'code') {
-        $self->[CODEGET] = $params{$_};
-        $self->[CODEPUT] = $params{$_};
-    }
-    elsif (lc eq 'put') {
-        $self->[CODEPUT] = $params{$_};
-    }
-    elsif (lc eq 'get') {
-        $self->[CODEGET] = $params{$_};
-    }
+    next unless ($_ eq 'Put') || ($_ eq 'Get') || ($_ eq 'Code');
+    $self->[ {Put  => CODEPUT,
+              Get  => CODEGET,
+              Code => CODEBOTH
+             }->{$_}
+           ] = $params{$_};
   }
 }
 
@@ -111,22 +109,13 @@ POE::Filter::Map - POE Data Mapping Filter
 
 =head1 SYNOPSIS
 
-  $filter = POE::Filter::Map->new(
-      Code => sub {...},
-      );
-
-  $filter = POE::Filter::Map->new(
-      Put => sub {...},
-      Get => sub {...},
-      );
-  
+  $filter = POE::Filter::Map->new(Code => sub {...});
+  $filter = POE::Filter::Map->new(Put => sub {...}, Get => sub {...});
   $arrayref_of_transformed_data = $filter->get($arrayref_of_raw_data);
-  
   $arrayref_of_streamable_data = $filter->put($arrayref_of_data);
   $arrayref_of_streamable_data = $filter->put($single_datum);
-  
-  $filter->modify( Code => sub {...} );
-  $filter->modify( Put  => sub {...}, Get => sub {...} );
+  $filter->modify(Code => sub {...});
+  $filter->modify(Put => sub {...}, Get => sub {...});
 
 =head1 DESCRIPTION
 
@@ -139,7 +128,7 @@ the C<map> builtin function.
 
 =over 4
 
-=item modify
+=item *
 
 POE::Filter::Map::modify
 
@@ -172,6 +161,3 @@ Please see the POE manpage for more information about authors and
 contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
