@@ -1,4 +1,4 @@
-# $Id: Pipe.pm 2274 2008-02-25 05:56:36Z rcaputo $
+# $Id: Pipe.pm,v 1.12 2003/11/26 03:52:06 rcaputo Exp $
 
 # Common routines for POE::Pipe::OneWay and ::TwoWay.  This is meant
 # to be inherited.  This is ugly, messy code right now.  It fails
@@ -9,15 +9,11 @@ package POE::Pipe;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2274 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.12 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 use Symbol qw(gensym);
-use IO::Socket qw(
-  PF_INET SOCK_STREAM SOL_SOCKET SO_REUSEADDR 
-  pack_sockaddr_in unpack_sockaddr_in inet_aton
-  SOMAXCONN SO_ERROR
-);
-use POSIX qw(:fcntl_h);
+use IO::Socket;
+use POSIX qw(fcntl_h);
 use Errno qw(EINPROGRESS EWOULDBLOCK);
 
 # CygWin seems to have a problem with socketpair() and exec().  When
@@ -50,11 +46,11 @@ else {
   @preference = qw(socketpair pipe inet);
 }
 
-sub _get_next_preference {
+sub get_next_preference {
   return $preference[0];
 }
 
-sub _shift_preference {
+sub shift_preference {
   shift @preference;
 }
 
@@ -62,8 +58,8 @@ sub _shift_preference {
 
 BEGIN {
   if ($^O eq 'MSWin32') {
-    eval '*F_GETFL = sub () { 0 };';
-    eval '*F_SETFL = sub () { 0 };';
+    eval '*F_GETFL = sub { 0 };';
+    eval '*F_SETFL = sub { 0 };';
   }
 }
 
@@ -81,30 +77,29 @@ sub _stop_blocking {
   # RCC 2003-01-20: Perl 5.005_03 doesn't like blocking(), so we'll
   # only call it in perl 5.8.0 and beyond.
 
-  # Do it the Win32 way.
-  if ($^O eq 'MSWin32') {
-    my $set_it = "1";
-
-    # 126 is FIONBIO (some docs say 0x7F << 16)
-    ioctl(
-      $socket_handle,
-      0x80000000 | (4 << 16) | (ord('f') << 8) | 126,
-      \$set_it
-    ) or die "ioctl fails: $!";
-    return;
-  }
-
-  # Do it the 5.8+ way.
   if ($] >= 5.008) {
     $socket_handle->blocking(0);
-    return;
   }
+  else {
+    # Do it the Win32 way.  XXX This is incomplete.
+    if ($^O eq 'MSWin32') {
+      my $set_it = "1";
 
-  # Do it the old way.
-  my $flags = fcntl($socket_handle, F_GETFL, 0) or die "getfl fails: $!";
-  $flags = fcntl($socket_handle, F_SETFL, $flags | O_NONBLOCK)
-    or die "setfl fails: $!";
-  return;
+      # 126 is FIONBIO (some docs say 0x7F << 16)
+      ioctl( $socket_handle,
+             0x80000000 | (4 << 16) | (ord('f') << 8) | 126,
+             $set_it
+           )
+        or die "ioctl fails: $!";
+    }
+
+    # Do it the way everyone else does.
+    else {
+      my $flags = fcntl($socket_handle, F_GETFL, 0) or die "getfl fails: $!";
+      $flags = fcntl($socket_handle, F_SETFL, $flags | O_NONBLOCK)
+        or die "setfl fails: $!";
+    }
+  }
 }
 
 # Another static member.  Turn blocking on when we're done, in case
@@ -121,36 +116,35 @@ sub _start_blocking {
   # RCC 2003-01-20: Perl 5.005_03 doesn't like blocking(), so we'll
   # only call it in perl 5.8.0 and beyond.
 
-  # Do it the Win32 way.
-  if ($^O eq 'MSWin32') {
-    my $unset_it = "0";
-
-    # 126 is FIONBIO (some docs say 0x7F << 16)
-    ioctl(
-      $socket_handle,
-      0x80000000 | (4 << 16) | (ord('f') << 8) | 126,
-      \$unset_it
-    ) or die "ioctl fails: $!";
-    return;
-  }
-
-  # Do it the 5.8+ way.
   if ($] >= 5.008) {
     $socket_handle->blocking(1);
-    return;
   }
+  else {
+    # Do it the Win32 way.  XXX This is incomplete.
+    if ($^O eq 'MSWin32') {
+      my $unset_it = "0";
 
-  # Do it the old way.
-  my $flags = fcntl($socket_handle, F_GETFL, 0) or die "getfl fails: $!";
-  $flags = fcntl($socket_handle, F_SETFL, $flags & ~O_NONBLOCK)
-    or die "setfl fails: $!";
-  return;
+      # 126 is FIONBIO (some docs say 0x7F << 16)
+      ioctl( $socket_handle,
+             0x80000000 | (4 << 16) | (ord('f') << 8) | 126,
+             $unset_it
+           )
+        or die "ioctl fails: $!";
+    }
+
+    # Do it the way everyone else does.
+    else {
+      my $flags = fcntl($socket_handle, F_GETFL, 0) or die "getfl fails: $!";
+      $flags = fcntl($socket_handle, F_SETFL, $flags & ~O_NONBLOCK)
+        or die "setfl fails: $!";
+    }
+  }
 }
 
 # Make a socket.  This is a homebrew socketpair() for systems that
 # don't support it.  The things I must do to make Windows happy.
 
-sub _make_socket {
+sub make_socket {
 
   ### Server side.
 
@@ -271,6 +265,3 @@ POE::Pipe is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
